%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                              %
%  LECC article class (single contribution)                    %
%                                                              %
%  1.00 (23 Jan. 2006)                                         %
%    - Initial version (from Word instructions and example)    %
%                                                              %
%  Last Mod.: 23 January 2006 (MG)                             %
%                                                              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\fileversion{1.00} 
\def\filedate{2006/01/23}
\def\docdate {2006/01/23}
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{leccart}%
    [\filedate\space leccart class (version\space\fileversion)]

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions
 
\LoadClass[a4paper,10pt,oneside]{article}

%%% Specifics for full CERN reports

\RequirePackage{tabularx,array,url,ifthen,multicol}

% Define page geometry
\usepackage{geometry}
\ifthenelse{\lengthtest{\paperwidth> 210mm}}%%% letter
 {\message{ **** letter ****}\geometry{% letersized paper
   paperwidth=8.5in,
   paperheight=11in,
   right=0.66in,
   bottom=0.75in,
   left=0.66in,
   top=0.36in,
   height=8.79in,
   width=7.71in,
   headsep=0in,
   footskip=0in,
   headheight=0in
  }}
 {\message{ ***** A4 *****}\geometry{% A4sized paper
   paperwidth=210mm,
   paperheight=297mm,
   right=14mm,
   bottom=19mm,
   left=14mm,
   top=27mm,
  % height=241mm,
  % width=182mm,
   headsep=0mm,
   footskip=0mm,
   headheight=0mm
  }}

\message{ cls: textwidth=\the\textwidth, textheight=\the\textheight }

%% Text font is Times Roman
\renewcommand{\rmdefault}{ptm}

\pagestyle{empty}

%\setlength{\columnsep}{5.4mm}
%\setlength{\columnseprule}{0mm}
 
% \@startsection {NAME}{LEVEL}{INDENT}{BEFORESKIP}{AFTERSKIP}{STYLE}
%            optional * [ALTHEADING]{HEADING}
%    Generic command to start a section.
%    NAME       : e.g., 'subsection'
%    LEVEL      : a number, denoting depth of section -- i.e., section=1,
%                 subsection = 2, etc.  A section number will be printed
%                 if and only if LEVEL < or = the value of the
%                 secnumdepth counter.
%    INDENT     : Indentation of heading from left margin
%    BEFORESKIP : Absolute value = skip to leave above the heading.
%                 If negative, then paragraph indent of text following
%                 heading is suppressed.
%    AFTERSKIP  : if positive, then skip to leave below heading,
%                       else - skip to leave to right of run-in heading.
%    STYLE      : commands to set style
%  If '*' missing, then increments the counter.  If it is present, then
%  there should be no [ALTHEADING] argument.  A sectioning command
%  is normally defined to \@startsection + its first six arguments.
 
\def\section{\@startsection {section}{1}{\z@}{12pt plus .5pt minus
    .1ex}{4pt plus .1pt}{\large\sc\centering}}
\def\subsection{\@startsection{subsection}{2}{\parindent}{8pt plus .5pt
     minus .1pt}{4pt plus .1pt}{\large\itshape}}
\def\subsubsection{\@startsection{subsubsection}{2}{\z@}{8pt plus .5pt
     minus .1pt}{4pt plus .1pt}{\normalsize\itshape}}
 
\def\thesection{\Roman{section}.}
\def\thesubsection{\Alph{subsection}.}
\def\thesubsubsection{\arabic{subsection})}
 
\setcounter{secnumdepth}{3}
 
\def\@seccntformat#1{\csname the#1\endcsname\hspace{0.5em}}% was \quad

\def\thebibliography#1{\section*{References}\list
 {[\arabic{enumi}]}{\settowidth\labelwidth{[#1]}\leftmargin\labelwidth
 \advance\leftmargin\labelsep
 \usecounter{enumi}}
 \def\newblock{\hskip .11em plus .33em minus .07em}
 \sloppy\clubpenalty4000\widowpenalty4000
 \sfcode`\.=1000\relax}
\let\endthebibliography=\endlist
 
%-----------------------------------------------------------------------
 
%    ****************************************
%    *               TITLE                  *
%    ****************************************
%
% This definition of \maketitle taken from article.sty, except
% it does not do a \thispagestyle{plain}.
 
\def\maketitle{\par
 \begingroup
   \def\thefootnote{\fnsymbol{footnote}}
   \def\@makefnmark{\hbox
       to 0pt{$^{\@thefnmark}$\hss}}
%   \begin{multicols}{2}[\@maketitle]
 \@maketitle
 \@thanks
 \endgroup
 \setcounter{footnote}{0}
 \let\maketitle\relax
 \let\@maketitle\relax
 \gdef\@thanks{}\gdef\@author{}\gdef\@title{}\let\thanks\relax}
 
\newlength{\titleblockheight}       % so user can change it if need be
\setlength{\titleblockheight}{4cm}
 
%%       \titlblockheight introduced at 16:52:55 on 9 Jun 1990 by JOWETT
 
\iffalse
\def\@maketitle{\vbox to \titleblockheight {\hsize\textwidth
  \linewidth\hsize \vfil \centering
  {\Large \@title \par}     % Title set in \LARGE size.
  \vskip 2ex                % Vertical space after title.
  {\large \begin{tabular}[t]{c}\@author \end{tabular}\par}
  \vfil}}
\fi
\def\@maketitle{%
\begin{center}
\Large \@title\\[14pt]
\large \begin{tabular}[t]{c}\@author \end{tabular}
\end{center}}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Floats                                                          %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Define caption layout %%%%%

\newcommand{\setskiptab}{%
 \setlength\abovecaptionskip{10pt}
 \setlength\belowcaptionskip{4pt}}
\newcommand{\setskipfig}{%
 \setlength\abovecaptionskip{4pt}
 \setlength\belowcaptionskip{10pt}}
\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  \begin{center}\small{#1:} #2\end{center}
  \vskip\belowcaptionskip}
\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{\small #1: #2}%
  \ifdim \wd\@tempboxa >\hsize
   \small #1: #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}

\renewenvironment{table}
               {\@float{table}[H]\setskiptab\small}
               {\end@float}
\renewenvironment{table*}
               {\@dblfloat{table}[H]\setskiptab\small}
               {\end@dblfloat}
\renewenvironment{figure}
               {\@float{figure}[H]\setskipfig}
               {\end@float}
\renewenvironment{figure*}
               {\@dblfloat{figure}[H]\setskipfig}
               {\end@dblfloat}

\ifx\@Hxfloat\@Hundef\else\expandafter\endinput\fi
\let\@Hxfloat\@xfloat
\def\@xfloat#1[{\@ifnextchar{H}{\@HHfloat{#1}[}{\@Hxfloat{#1}[}}
\def\@HHfloat#1[H]{%
\expandafter\let\csname end#1\endcsname\end@Hfloat
\vskip\intextsep\vbox\bgroup\def\@captype{#1}\parindent\z@
\ignorespaces}
\def\end@Hfloat{\egroup\vskip \intextsep}
 
% The abstract Environment
 
\renewenvironment{abstract}
{\begin{center}\large\textit{Abstract}\\[4pt]\end{center}}
{\par}
 
%    ****************************************
%    *           INITIALIZATION             *
%    ****************************************
%
% Default initializations
 
%\twocolumn
\sloppy
\parindent 5mm  \parskip4pt
\leftmargini 2em
\leftmargin\leftmargini
\leftmarginv .5em
\leftmarginvi .5em
\flushbottom

%%%% Commands for use in the example file

\providecommand\Lcs[1]{\texttt{\textbackslash #1}}
\providecommand\Lcsa[2]{\texttt{\textbackslash #1\{\emph{#2}\}}}
\providecommand\Lenvb[1]{\texttt{\textbackslash begin\{#1\}}}
\providecommand\Lenve[1]{\texttt{\textbackslash end\{#1\}}}

\endinput
